.. _event_concept:

================
The Event System
================

.. contents::
   :depth: 2
   :local:
   :backlinks: none

Outline
-------
 - Event creators
 - Event listeners
 - Perils of an event system in a simulation.
